/* 
Copyright (c) FlapMX LLC.
This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/

/* General Variables */
:root {
  --file-upload-color: #efefef;
  --header-font: "Nunito", sans-serif;
  --content-font: "Lora", serif;
}

/* text sizes */
.text-x-large {
  font-size: 2rem;
}

.text-large {
  font-size: 1.25rem;
}

.text-medium {
  font-size: 1.125rem;
}

.text-small {
  font-size: 0.875rem;
}

.text-x-small {
  font-size: 0.75rem;
}

/* letter spacing */
.letter-spacing {
  letter-spacing: 0.05rem;
}

.chart-container svg text {
  letter-spacing: 0.05rem;
}

body {
  background-color: #f3f3f3 !important;
  font-family: var(--content-font);
  color: rgb(255, 255, 255);
  padding-top: 125px;
}

.container-fluid-side {
  margin: 0 auto !important;
  /*max-height: 100px;*/

  text-align: justify;
  -ms-text-justify: distribute-all-lines;
  text-justify: distribute-all-lines;

  justify-content: center;
  align-items: center;
}

/* navbar styles */
nav {
  font-family: var(--header-font);
  font-size: 1.1rem;
  background-color: #2f2f2f;
  color: #f2f2f2;
}

.nav-out-links a {
  font-family: var(--header-font);
  margin: 0 20px 0 0;
  color: #f2f2f2;
  font-size: 1.2rem;
}

.nav-out-links a:hover {
  color: #ffffff;
  transition: 0.2s letter-spacing ease-in;
  letter-spacing: 1px;
  text-decoration: none;
}

.logo-header {
  font-family: var(--header-font);
  display: flex;
  align-items: center;
  padding-bottom: 8px;
}

.logo-header img {
  width: 60px;
  border-radius: 7px;
}
.logo-header span {
  color: #f0ca05;
}

.logo-header h1 {
  letter-spacing: 0.5px;
  font-size: 1.6rem;
  margin: 0 20px 0 0;
}

.is-white {
  background: rgb(255, 255, 255);
  height: 65px;
}

.is-dark {
  background: rgb(19, 25, 36);
}

/* user image style */
.img-container > img {
  width: 100px;
}

.previewBox:hover > .previewButton:enabled {
  background: white;
  color: #2f3640;
}

.previewBox:hover > .previewButton:disabled {
  cursor: not-allowed;
}

.previewButton {
  float: right;
  width: 35px;
  height: 35px;
  border-radius: 50%;
  background: #2f3640;
  display: flex;
  justify-content: center;
  align-items: center;
  transition: 0.4s;
}

.nav-previewButton {
  display: none;
}

.runBox {
  /*position: absolute;*/
  right: 13%;
  bottom: 50%;
  /*transform:  translate(-50%,50%);*/
  height: 40px;
}

.nav-runBox {
  height: 40px;
  border-radius: 40px;
}

.runBox:hover > .runButton:enabled {
  background: white;
  color: #2f3640;
}

.runButton {
  color: white;
  float: right;
  width: 35px;
  height: 35px;
  border-radius: 50%;
  display: flex;
  justify-content: center;
  align-items: center;
  transition: 0.4s;
}

.saveBox {
  /*position: absolute;*/
  bottom: 50%;
  right: 8%;
  /*transform:  translate(-50%,50%);*/
  height: 40px;
}

.saveBox-grid {
  height: 40px;
  border-radius: 40px;
  width: 200px;
  margin-left: auto;
  margin-right: auto;
}

.saveButton-grid {
  color: white;
  margin-top: 20px;
  width: 150px;
  height: 35px;
  border-radius: 12px;
  background: #2f3640;
  transition: 0.4s;
}

.saveButton-grid:hover {
  background: #f2f2f2;
}

.saveBox:hover > .saveButton:enabled {
  background: white;
  color: #2f3640;
}

.saveButton {
  color: white;
  float: right;
  width: 35px;
  height: 35px;
  border-radius: 50%;
  background: #2f3640;
  display: flex;
  justify-content: center;
  align-items: center;
  transition: 0.4s;
}

.searchButton {
  color: white;
  float: right;
  width: 40px;
  height: 40px;
  border-radius: 50%;
  background: #2f3640;
  display: flex;
  justify-content: center;
  align-items: center;
  transition: 0.4s;
}

.searchInput {
  border: none;
  background: none;
  outline: none;
  float: left;
  padding: 0;
  color: white;
  font-size: 16px;
  transition: 0.4s;
  line-height: 40px;
  width: 0px;
}

.previewDescription {
  color: #242424;
  overflow-y: auto;
  height: 200px;
}

.grid-card {
  padding: 1.5rem;
  width: 300px;
  /*height: 525px;*/
  vertical-align: top;
  display: inline-block;
  *display: inline;
  zoom: 1;
}

.card-heading {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: stretch;
  -ms-flex-align: stretch;
  align-items: stretch;
  -webkit-box-pack: center;
  -ms-flex-pack: center;
  justify-content: space-between;
  position: relative;
  min-height: 30px;
  text-align: center;
}

.is-card-dark {
  background: rgb(32, 42, 59) !important;
}

.logo-adjust {
  margin-top: -4px;
}

.col-md-8.border-left {
  border-left: 1px solid rgba(222, 226, 230, 0.07) !important;
}

.fab {
  color: rgb(255, 255, 255);
  opacity: 0.6;
}

.conv > span {
  display: inline-block;
  min-width: 75px !important;
}

.chart-container > * {
  height: 100% !important;
}

.full-height.border-left,
.full-height.border-right {
  border-left: 1px solid rgba(255, 255, 255, 0.1) !important;
  border-right: 1px solid rgba(255, 255, 255, 0.1) !important;
}

.custom-dropdown {
  border-radius: 4px;
  background: transparent;
  border: 1px solid rgba(193, 204, 222, 0.2);
  font-family: var(--content-font);
}

.Dropdown-menu {
  max-height: 300px;
}

.Dropdown-control {
  border: none;
  color: #c1ccde;
  background: transparent;
}

.Dropdown-arrow {
  top: 18px;
}

.people-img {
  height: 50px;
  width: 50px;
}

.keywords {
  padding: 1rem;
  width: 3px;
  box-shadow: 0 15px 30px 0 rgba(0, 0, 0, 0.11),
    0 5px 15px 0 rgba(0, 0, 0, 0.08);
  background-color: rgb(23, 32, 46) !important;
  border-radius: 0.5rem;
  font-family: var(--content-font);
  font-size: 15px;
}

/* ----- Custom CSS ----- */
.custom-button {
  margin: 16px;
}

.custom-fixed-top {
  position: fixed;
  top: 0;
  right: 0;
  left: 0;
}

.custom-row {
  background-color: #ffffff;
  margin-bottom: 15px;
}

.custom-file-upload {
  font-family: var(--content-font);
  font-size: 16px;
  max-width: 15em;
  margin: 16px;
}

.custom-preview {
  background: #f2f2f2;
  width: 90%;
  height: 200px;
  border-radius: 3px;
}

.tab-list {
  padding-left: 0;
}

.tab-list-item {
  color: #f2f2f2;
  background-color: inherit;
  float: left;
  border-bottom: 4px solid #2f2f2f;
  outline: none;
  cursor: pointer;
  padding: 14px 16px;
  transition: 0.3s;
}

.tab-list-item:hover {
  background-color: #ddd;
}

.tab-list-active {
  border: solid #f2f2f2;
  border-width: 0px 0px 4px 0px;
}

/* ----- Custom CSS ----- */
/* ----- Select Box Black Panther ----- */

.sel_task {
  display: inline-block;
  margin: 3em 2em;
  width: 225px;
  background-color: transparent;
  position: relative;
  cursor: pointer;
}

.sel_task::before {
  content: "▲";
  font-family: var(--content-font);
  position: absolute;
  color: #f9f9f9;
  right: 20px;
  top: 0.3em;
}

.sel_task.active::before {
  transform: rotateX(-180deg);
}

.sel_task__placeholder {
  display: block;
  font-family: var(--content-font);
  color: #f9f9f9;
  padding: 0.2em 0.5em;
  text-align: left;
  pointer-events: none;
  user-select: none;
  visibility: visible;
}

.sel_task.active .sel_task__placeholder {
  visibility: hidden;
}

.sel_task__placeholder::before {
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  padding: 0.2em 0.5em;
  content: attr(data-placeholder);
  visibility: hidden;
}

.sel_task.active .sel_task__placeholder::before {
  visibility: visible;
}

.sel_task__box {
  position: absolute;
  top: calc(100% + 4px);
  left: -4px;
  display: none;
  list-style-type: none;
  text-align: left;
  background-color: #164267;
  width: calc(100% + 8px);
  box-sizing: border-box;
}

.sel_task.active .sel_task__box {
  display: block;
  animation: fadeInUp 500ms;
}

.sel_task__box__options {
  display: list-item;
  font-family: var(--content-font);
  color: #f9f9f9;
  text-align: center;
  user-select: none;
}

.sel_task__box__options::after {
  content: "▼";
  font-family: var(--content-font);
  margin-left: 5px;
  display: none;
  top: 0.3em;
}

.sel_task__box__options.selected::after {
  display: inline;
}

.sel_task__box__options:hover {
  background-color: #039be5;
}

.sel_task {
  border-bottom: 4px solid rgba(0, 0, 0, 0.3);
}

.sel_task--black-panther {
  z-index: 3;
}

.sel_model {
  display: inline-block;
  margin: 3em 2em;
  width: 225px;
  background-color: transparent;
  position: relative;
  cursor: pointer;
}

.sel_model::before {
  content: "▲";
  font-family: var(--content-font);
  position: absolute;
  color: #f9f9f9;
  right: 20px;
  top: 0.3em;
}

.sel_model.active::before {
  transform: rotateX(-180deg);
}

.sel_model__placeholder {
  display: block;
  font-family: var(--content-font);
  color: #f9f9f9;
  padding: 0.2em 0.5em;
  text-align: left;
  pointer-events: none;
  user-select: none;
  visibility: visible;
}

.sel_model.active .sel_model__placeholder {
  visibility: hidden;
}

.sel_model__placeholder::before {
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  padding: 0.2em 0.5em;
  content: attr(data-placeholder);
  visibility: hidden;
}

.sel_model.active .sel_model__placeholder::before {
  visibility: visible;
}

.sel_model__box {
  position: absolute;
  top: calc(100% + 4px);
  left: -4px;
  display: none;
  list-style-type: none;
  text-align: left;
  background-color: #164267;
  width: calc(100% + 8px);
  box-sizing: border-box;
}

.sel_model.active .sel_model__box {
  display: block;
  animation: fadeInUp 500ms;
}

.sel_model__box__options {
  display: list-item;
  font-family: var(--content-font);
  color: #f9f9f9;
  text-align: center;
  user-select: none;
}

.sel_model__box__options::after {
  content: "▼";
  font-family: var(--content-font);
  margin-left: 5px;
  display: none;
  top: 0.3em;
}

.sel_model__box__options.selected::after {
  display: inline;
}

.sel_model__box__options:hover {
  background-color: #039be5;
}

.sel_model {
  border-bottom: 4px solid rgba(0, 0, 0, 0.3);
}

.sel_model--black-panther {
  z-index: 3;
}
/* ----- Select Box Black Panther ----- */

.file-upload-wrapper {
  position: relative;
  margin-bottom: 5px;
  border: 1px solid #ccc;
}
.file-upload-input {
  width: 300px;
  color: #fff;
  font-size: 16px;
  padding: 11px 17px;
  border: none;
  background-color: var(--file-upload-color);
}

.select-box {
  position: relative;
  max-width: 20em;
  margin: 5em auto;
  width: 100%;
}

.select,
.label {
  color: #414141;
  display: block;
  font: 400 17px/2em "Source Sans Pro", sans-serif;
}

.select {
  width: 100%;
  position: absolute;
  top: 0;
  padding: 5px 0;
  height: 40px;
  opacity: 0;
  filter: 0;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
  background: none transparent;
  border: 0 none;
}
.select-box1 {
  background: #ececec;
}

.label {
  position: relative;
  padding: 5px 10px;
  cursor: pointer;
}
.open .label::after {
  content: "▲";
}
.label::after {
  content: "▼";
  font-size: 12px;
  position: absolute;
  right: 0;
  top: 0;
  padding: 5px 15px;
  border-left: 5px solid #fff;
}

/* media queries */
@media screen and (max-width: 991px) {
  .container-fluid.pr-5,
  .container-fluid.pl-5 {
    width: 90% !important;
    padding-left: 0 !important;
    padding-right: 0 !important;
  }
}

@media screen and (min-width: 991px) {
  .full-height {
    height: 100% !important;
  }
}

@media screen and (max-width: 567px) {
  .full-height.border-left,
  .full-height.border-right {
    border-left: none !important;
    border-right: none !important;
  }

  .chart-container {
    height: 180px !important;
  }

  .large {
    height: 350px !important;
  }
}

@media screen and (max-width: 620px) {
  .searchBox:hover > .searchInput {
    width: 150px;
    padding: 0 6px;
  }
}
