// Copyright (c) FlapMX LLC.
// This source code is licensed under the MIT license found in the
// LICENSE file in the root directory of this source tree.

export const TaskData = [
  {
    label: "Named-Entity-Recognition",
    value: "ner",
  },
];
