// Copyright (c) FlapMX LLC.
// This source code is licensed under the MIT license found in the
// LICENSE file in the root directory of this source tree.

export const TabData = [
  {
    title: "Gauge",
    path: "/",
    cName: "tab-list-item",
  },
  {
    title: "Metrics",
    path: "/metrics",
    cName: "tab-list-item",
  },
  {
    title: "History",
    path: "/history",
    cName: "tab-list-item",
  },
];
