/* 
Copyright (c) FlapMX LLC.
This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/

/* History Page */
.data-grid-container {
  background-color: #ffffff;
  width: 90%;
  margin: 0 auto;
  display: flex;
  justify-content: flex-start;
  box-shadow: 0 8px 8px -6px rgba(0, 0, 0, 0.19);
}

.history-header {
  padding: 0 0 10px 0;
  width: 90%;
  margin: 0 auto;
  display: flex;
  justify-content: flex-end;
}

.search-bar {
  display: flex;
  align-items: center;
}

.search-bar button {
  border-radius: 3px;
  background: none;
  font-weight: 500;
  border: 2px solid #3483ed;
  color: #3483ed;
  margin-left: 10px;
  height: 40px;
}

.search-bar button:hover {
  color: #78abee;
  border-color: #78abee;
}

.pagination-div {
  padding-top: 20px;
  display: flex;
  justify-content: center;
  align-items: center;
  margin: 0 auto;
  width: 50%;
}

.pagination-div button {
  color: #5c5c5c;
  border: 1px #5c5c5c solid;
  margin: 10px;
  font-size: 1.1rem;
  width: 40px;
  height: 40px;
  border-radius: 50%;
}

.pagination-div button:hover {
  color: #bdbdbd;
  border-color: #bdbdbd;
}

.pagination-div button::selection,
.pagination-div button:focus {
  outline: none;
}

.pagination-div button:disabled {
  color: #bdbdbd;
  border-color: #bdbdbd;
}

.pagination-div p {
  margin: 0 0 0 15px;
  font-size: 1.3rem;
}

/* Home Page */

.home-container {
  background: #ffffff;
  width: 90%;
  margin: 0 auto 50px auto;
  box-shadow: 0 8px 8px -6px rgba(0, 0, 0, 0.19);
}

.channel-container {
  padding: 0 30px;
}

/* Metrics Page */
.chart-container {
  width: 90%;
  min-width: 820px;
  margin: 0 auto 40px auto;
  padding: 20px 0;
  background-color: #ffffff;
  display: flex;
  justify-content: center;
  box-shadow: 0 8px 8px -6px rgba(0, 0, 0, 0.19);
}

.bar-div {
  width: 800px;
}

.bar-div h2 {
  font-family: "Nunito", sans-serif;
  text-align: center;
  padding-left: 70px;
  margin-bottom: 30px;
}
