// Copyright (c) FlapMX LLC.
// This source code is licensed under the MIT license found in the
// LICENSE file in the root directory of this source tree.

export const historyTest = [
  {
    id: 123,
    task: "ner",
    model: "some model",
    status: "complete",
    completion_time: new Date(),
  },
  {
    id: 234,
    task: "ner",
    model: "some model",
    status: "complete",
    completion_time: new Date(),
  },
  {
    id: 345,
    task: "ner",
    model: "some model",
    status: "complete",
    completion_time: new Date(),
  },
  {
    id: 456,
    task: "ner",
    model: "some model",
    status: "complete",
    completion_time: new Date(),
  },
  {
    id: 222,
    task: "ner",
    model: "some model",
    status: "complete",
    completion_time: new Date(),
  },
  {
    id: 333,
    task: "ner",
    model: "some model",
    status: "complete",
    completion_time: new Date(),
  },
  {
    id: 444,
    task: "ner",
    model: "some model",
    status: "complete",
    completion_time: new Date(),
  },
  {
    id: 555,
    task: "ner",
    model: "some model",
    status: "complete",
    completion_time: new Date(),
  },
  {
    id: 666,
    task: "ner",
    model: "some model",
    status: "complete",
    completion_time: new Date(),
  },
  {
    id: 777,
    task: "ner",
    model: "some model",
    status: "complete",
    completion_time: new Date(),
  },
];
