/* 
Copyright (c) FlapMX LLC.
This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/

/* Header Column  */

.column-header {
  display: flex;
}

.column-header h2 {
  font-size: 1.4rem;
}

.column-header .fill-block {
  width: 50px;
}

@media screen and (max-width: 1195px) {
  .column-header .fill-block {
    width: 0;
  }
}

/* Add Channel Button */

.channel-button-container {
  display: flex;
  justify-content: flex-start;
  align-items: center;
}

.channel-button {
  margin: 0 0 8px 0;
  font-size: 1.7rem;
  cursor: pointer;
  color: #242424;
  border: none;
  background: none;
  color: #0664b2;
}

.channel-button:disabled {
  color: #bdbdbd;
}

.channel-button:disabled:hover {
  color: #bdbdbd;
}

.channel-button:hover {
  color: #7aadf1;
}

.channel-button::selection,
.channel-button:focus {
  outline: none;
}

/* General Buttons And Action Button Div */

.MuiCircularProgress-colorPrimary {
  color: #7aadf1 !important;
}
.buttons-div {
  height: 250px;
  width: 50px;
  display: flex;
  align-items: center;
  justify-content: space-evenly;
  flex-flow: column nowrap;
}

.buttons-div .button-generic:disabled {
  color: #bdbdbd;
}

.buttons-div .fa-check-circle,
.buttons-div .fa-exclamation-circle,
.buttons-div .fa-bed {
  font-size: 2rem;
}

.buttons-div .fa-check-circle {
  color: green;
}

.buttons-div .fa-exclamation-circle {
  color: red;
}

.buttons-div .fa-bed {
  color: #bdbdbd;
}

.button-generic {
  background: none;
  border: none;
  font-size: 2rem;
  margin: 2px 0;
  color: #0664b2;
}

.button-generic:hover {
  color: #7aadf1;
}

.button-generic::selection,
.button-generic:focus {
  outline: none;
}

.config-label {
  cursor: pointer;
  margin: 0 10px;
  padding: 1px 6px;
}

@media screen and (max-width: 1275px) {
  .buttons-div {
    height: auto;
    width: 30%;
    margin: 0 auto 10px auto;
    flex-flow: row nowrap;
  }
}

/* File Upload */

.file-upload-label {
  margin: 0;
}

.file-upload-label-container {
  display: flex;
  align-items: center;
  justify-content: space-between;
}

.file-upload-label-container i {
  color: green;
  display: block;
  margin-left: 10px;
}

.file-upload-label-container .fa-trash-alt {
  cursor: pointer;
  color: #242424;
}
